<?php
/**
 * Cobber functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Cobber
 */


if ( ! function_exists( 'cobber_after_theme_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */

	function cobber_after_theme_support() {

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Custom background color.
		add_theme_support(
			'custom-background',
			array(
				'default-color' => 'ffffff',
			)
		);

		// This variable is intended to be overruled from themes.
		// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
		$GLOBALS['content_width'] = apply_filters( 'cobber_content_width', 1140 );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		/*
		 * Posts Forcobber.
		 *
		 * https://wordpress.org/support/article/post-formats/
		 */
		add_theme_support( 'post-formats', array(
		    'video',
		    'audio',
		    'gallery',
		    'quote',
		    'image'
		) );

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Cobber, use a find and replace
		 * to change 'cobber' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'cobber', get_template_directory() . '/languages' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );
        add_theme_support( 'wp-block-styles' );

	}

endif;

add_action( 'after_setup_theme', 'cobber_after_theme_support' );

function cobber_widgets_init(){
    
    register_sidebar( array(
        'name' => esc_html__('Footer Widget One', 'cobber'),
        'id' => 'cobber-footer-1',
        'description' => esc_html__('Add widgets here.', 'cobber'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ));

    register_sidebar( array(
        'name' => esc_html__('Footer Widget Two', 'cobber'),
        'id' => 'cobber-footer-2',
        'description' => esc_html__('Add widgets here.', 'cobber'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ));

}

add_action('widgets_init', 'cobber_widgets_init');

function cobber_next_posts_link( $max_page = 0 ) {
    global $paged, $wp_query;

    if ( ! $max_page ) {
        $max_page = $wp_query->max_num_pages;
    }

    if ( ! $paged ) {
        $paged = 1;
    }

    $next_page = (int) $paged + 1;
    if ( ( $next_page <= $max_page ) ) {
        /**
         * Filters the anchor tag attributes for the next posts page link.
         *
         * @since 2.7.0
         *
         * @param string $attributes Attributes for the anchor tag.
         */
        $attr = apply_filters( 'next_posts_link_attributes', '' );

        return sprintf(next_posts( $max_page, false ));
    }
}

/**
 * Register and Enqueue Styles.
 */
function cobber_register_styles() {

	$theme_version = wp_get_theme()->get( 'Version' );
	$fonts_url = cobber_fonts_url();
    if( $fonts_url ){
    	
    	require_once get_theme_file_path( 'assets/lib/custom/css/wptt-webfont-loader.php' );
        wp_enqueue_style(
			'cobber-google-fonts',
			wptt_get_webfont_url( $fonts_url ),
			array(),
			$theme_version
		);
    }

    wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/lib/slick/css/slick.min.css');
    wp_enqueue_style( 'cobber-style', get_stylesheet_uri(), array(), $theme_version );

    wp_style_add_data('cobber-style', 'rtl', 'replace');


    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}	

	wp_enqueue_script( 'imagesloaded' );
    wp_enqueue_script( 'masonry' );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/assets/lib/slick/js/slick.min.js', array('jquery'), '', 1);
	wp_enqueue_script( 'cobber-pagination', get_template_directory_uri() . '/assets/lib/custom/js/pagination.js', array('jquery'), '', 1 );
	wp_enqueue_script( 'cobber-custom', get_template_directory_uri() . '/assets/lib/custom/js/custom.js', array('jquery'), '', 1);

	$ajax_nonce = wp_create_nonce('cobber_ajax_nonce');
	
    // Global Query
    if( is_front_page() ){

    	$posts_per_page = absint( get_option('posts_per_page') );
        $twp_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
        $posts_args = array(
            'posts_per_page'        => $posts_per_page,
            'paged'                 => $twp_paged,
        );
        $posts_qry = new WP_Query( $posts_args );
        $max = $posts_qry->max_num_pages;
        wp_reset_postdata();
    }else{
        global $wp_query;
        $max = $wp_query->max_num_pages;
        $twp_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
    }

    $cobber_default = cobber_get_default_theme_options();
    $cobber_pagination_layout = get_theme_mod( 'cobber_pagination_layout',$cobber_default['cobber_pagination_layout'] );
    // Get the permalink structure from WordPress settings.
    $permalink_structure = get_option('permalink_structure');
    // Pagination Data
    wp_localize_script( 
	    'cobber-pagination', 
	    'cobber_pagination',
	    array(
	        'paged'  => absint( $twp_paged ),
	        'maxpage'   => absint( $max ),
            'nextLink'   => cobber_next_posts_link($max ),
	        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	        'loadmore'   => esc_html__( 'Load More Posts', 'cobber' ),
	        'nomore'     => esc_html__( 'No More Posts', 'cobber' ),
	        'loading'    => esc_html__( 'Loading...', 'cobber' ),
	        'pagination_layout'   => esc_html( $cobber_pagination_layout ),
            'permalink_structure' => esc_html($permalink_structure),
	        'ajax_nonce' => $ajax_nonce,
	     )
	);

    global $post;
    $single_post = 0;
    $cobber_ed_post_reaction = '';
    if( isset( $post->ID ) && isset( $post->post_type ) && $post->post_type == 'post' ){

    	$cobber_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'cobber_ed_post_reaction', true ) );
    	$single_post = 1;

    }
	wp_localize_script(
	    'cobber-custom', 
	    'cobber_custom',
	    array(
	    	'single_post'	=> absint( $single_post ),
	        'cobber_ed_post_reaction'  		=> esc_html( $cobber_ed_post_reaction ),
	        'next_svg'   => cobber_the_theme_svg('chevron-right',true),
            'prev_svg' => cobber_the_theme_svg('chevron-left',true),
            'play' => cobber_the_theme_svg( 'play', $return = true ),
            'pause' => cobber_the_theme_svg( 'pause', $return = true ),
            'mute' => cobber_the_theme_svg( 'mute', $return = true ),
            'unmute' => cobber_the_theme_svg( 'unmute', $return = true ),
            'play_text' => esc_html__('Play','cobber'),
            'pause_text' => esc_html__('Pause','cobber'),
            'mute_text' => esc_html__('Mute','cobber'),
            'unmute_text' => esc_html__('Unmute','cobber'),
	     )
	);

}

add_action( 'wp_enqueue_scripts', 'cobber_register_styles' );

/**
 * Admin enqueue script
 */
function cobber_admin_scripts($hook){

	wp_enqueue_media();
    wp_enqueue_style('cobber-admin', get_template_directory_uri() . '/assets/lib/custom/css/admin.css');
    wp_style_add_data('cobber-admin', 'rtl', 'replace');

    wp_enqueue_script('cobber-admin-js', get_template_directory_uri() . '/assets/lib/custom/js/admin.js', array('jquery'), '', 1);
    
    $ajax_nonce = wp_create_nonce('cobber_ajax_nonce');
            
    wp_localize_script( 
        'cobber-admin-js', 
        'cobber_admin',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,
            'active' => esc_html__('Active','cobber'),
            'deactivate' => esc_html__('Deactivate','cobber'),
            'upload_image'   =>  esc_html__('Choose Image','cobber'),
            'use_image'   =>  esc_html__('Select','cobber'),
         )
    );

    $current_screen = get_current_screen();
    if( $current_screen->id === "widgets" ) {

        // Enqueue Script Only On Widget Page.
        wp_enqueue_media();
    	wp_enqueue_script('cobber-widget', get_template_directory_uri() . '/assets/lib/custom/js/widget.js', array('jquery'), '', 1);
	}

}

add_action('admin_enqueue_scripts', 'cobber_admin_scripts');

function cobber_customize_preview_js() {
	wp_enqueue_script( 'cobber-customizer-preview', get_template_directory_uri() . '/assets/lib/custom/js/customizer-preview.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'cobber_customize_preview_js' );

if( !function_exists( 'cobber_js_no_js_class' ) ) :

	// js no-js class toggle
	function cobber_js_no_js_class() { ?>

		<script>document.documentElement.className = document.documentElement.className.replace( 'no-js', 'js' );</script>
	
	<?php
	}
	
endif;

add_action( 'wp_head', 'cobber_js_no_js_class' );

/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function cobber_menus() {

	$locations = array(
		'cobber-primary-menu'  => __( 'Primary Menu', 'cobber' ),
		'cobber-footer-menu'  => __( 'Footer Menu', 'cobber' ),
		'cobber-social-menu'  => __( 'Social Menu', 'cobber' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'cobber_menus' );



require get_template_directory() . '/classes/class-svg-icons.php';
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/single-related-posts.php';
require get_template_directory() . '/inc/custom-functions.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/classes/body-classes.php';
require get_template_directory() . '/inc/metabox.php';
require get_template_directory() . '/inc/pagination.php';
require get_template_directory() . '/assets/lib/tgmpa/recommended-plugins.php';
require get_template_directory() . '/woocommerce/woocommerce-function.php';
require get_template_directory() . '/inc/term-meta.php';
require get_template_directory() . '/inc/widgets/widget-base-class.php';
require get_template_directory() . '/inc/widgets/author.php';
require get_template_directory() . '/inc/widgets/recent-post.php';
require get_template_directory() . '/inc/widgets/social-link.php';
require get_template_directory() . '/inc/widgets/tab-posts.php';
require get_template_directory() . '/inc/widgets/category.php';
require get_template_directory() . '/classes/about.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/classes/plugins-classes.php';

add_filter('themeinwp_enable_demo_import_compatiblity','cobber_demo_import_filter_apply');

if( !function_exists('cobber_demo_import_filter_apply') ):

	function cobber_demo_import_filter_apply(){

		return true;

	}

endif;